
# Palette

A simple Python script for generating a color palette based on a given image/wallpaper




## Installation

Installing palette.py using pip

```bash
    pip install palette-gen
```


Installing from source/using from source

```bash
    git clone https://github.com/auth-xyz/palette
    cd palette
    python3 color_palette/color_palette.py 
```



## Usage

```bash
palette <path to image> <amount of colors>
// Example
palette $HOME/.wallpapers/some_wallpaper.png

┏━━━━━━━┳━━━━━━━━━━┓
┃ Color ┃ Hex Code ┃
┡━━━━━━━╇━━━━━━━━━━┩
│ █████ │ #b97c8e  │
│ █████ │ #6a6279  │
│ █████ │ #2e3440  │
│ █████ │ #614753  │
│ █████ │ #556682  │
└───────┴──────────┘

```